"""A module for the text replacing window."""
import wx.stc
from kvalikirstu2 import argument_parser
from kvalikirstu2 import gui_utils
from kvalikirstu2 import progress_dialog
from kvalikirstu2.localization import _


class TextReplaceWindow(wx.Dialog):
    """ Window for replacing text in files.
    """
    def __init__(self, model):
        """
        """
        super().__init__(None, title=_("Replace text in data files"))
        self.model = model
        self.args = argument_parser.get_args()
        self.files = ""
        self._init_window()

    def _init_window(self):
        self.panel = wx.Panel(self)
        sizer = wx.GridBagSizer(hgap=5, vgap=5)
        sizer.Add(wx.StaticText(self.panel, id=wx.ID_ANY, label=_("Original text")),
                  pos=(0, 0), border=self.args.padding)
        self.text1 = wx.TextCtrl(parent=self.panel, size=(300, 100), style=wx.TE_MULTILINE)
        sizer.Add(self.text1, pos=(1, 0), border=self.args.padding)
        sizer.Add(wx.StaticText(self.panel, id=wx.ID_ANY, label=_("New text")),
                  pos=(2, 0), border=self.args.padding)
        self.text2 = wx.TextCtrl(parent=self.panel, size=(300, 100), style=wx.TE_MULTILINE)
        sizer.Add(self.text2, pos=(3, 0), border=self.args.padding)

        button_sizer = wx.BoxSizer(wx.HORIZONTAL)
        self.add_button = wx.Button(self.panel, label=_("Replace"))
        button_sizer.Add(self.add_button)
        self.cancel_button = wx.Button(self.panel, label=_("Cancel"))
        button_sizer.Add(self.cancel_button)
        sizer.Add(button_sizer, pos=(4, 0), flag=wx.ALIGN_RIGHT)

        sizer.AddGrowableCol(0)
        sizer.AddGrowableRow(1)
        gui_utils.add_border_and_fit(self, sizer, self.panel)
        self.Center()
        self._bind_buttons()

    def _bind_buttons(self):
        self.Bind(wx.EVT_BUTTON, lambda evt: self.EndModal(wx.ID_CANCEL), self.cancel_button)
        self.Bind(wx.EVT_BUTTON, self._done_pressed, self.add_button)

    def _done_pressed(self, _tmp):
        self.Close()
        self._replace_text()
        self.EndModal(wx.ID_SAVE)

    def _replace_text(self):
        original_text = self.text1.GetValue().replace('\n', '')
        new_text = self.text2.GetValue().replace('\n', '')
        with progress_dialog.Dialog(
                _("Replace text"),
                _("Replacing text..."),
                style=wx.PD_AUTO_HIDE) as dlg:
            self.files = dlg.run_function(
                self.model.replace_text, original_text, new_text, initial_msg=_("Replacing text..."))
            dlg.DestroyLater()
        self._show_finish_msg(original_text, new_text)

    def _show_finish_msg(self, old_text, new_text):
        if not self.files:
            with wx.MessageDialog(None, _("No match found for {}".format(old_text))) as dlg:
                dlg.ShowModal()
            return

        # msg = (_("Replaced text \"%s\" with text \"%s\" in files:") % (old_text, new_text)
        #        if self.files else _("No match found for %s" % old_text))

        with wx.Dialog(
            None, title="INFO", style=wx.DEFAULT_DIALOG_STYLE | wx.RESIZE_BORDER | wx.DIALOG_NO_PARENT
        ) as dlg:
            main_szr = wx.BoxSizer(wx.VERTICAL)
            orig_txt_box = wx.TextCtrl(dlg, value=old_text, style=wx.TE_MULTILINE)
            new_txt_box = wx.TextCtrl(dlg, value=new_text, style=wx.TE_MULTILINE)
            files_box = wx.TextCtrl(dlg, value=self.files, style=wx.TE_MULTILINE)
            btn_szr = dlg.CreateSeparatedButtonSizer(wx.OK)
            # text = wx.StaticText(dlg, label=msg)
            # text.Wrap(400)
            main_szr.Add(wx.StaticText(dlg, label=_("Replaced original text:")), 0, wx.EXPAND | wx.ALL, 1)
            main_szr.Add(orig_txt_box, 3, wx.EXPAND | wx.ALL, 7)
            main_szr.Add(wx.StaticText(dlg, label=_("With new text:")), 0, wx.EXPAND | wx.ALL, 1)
            main_szr.Add(new_txt_box, 3, wx.EXPAND | wx.ALL, 7)
            main_szr.Add(wx.StaticText(dlg, label=_("In files:")), 0, wx.EXPAND | wx.ALL, 1)
            main_szr.Add(files_box, 5, wx.EXPAND | wx.ALL, 7)
            main_szr.Add(btn_szr, 0, wx.EXPAND | wx.ALL, 7)
            dlg.SetSizerAndFit(main_szr)
            dlg.SetSize(400, 240)
            dlg.Center()
            dlg.ShowModal()
