""" Tests the csv generator.
"""

import unittest
import os
import csv
from kvalikirstu2 import study_reader
from kvalikirstu2 import csv_generator
from kvalikirstu2 import localization
from kvalikirstu2 import header_scanner
from kvalikirstu2.data_archive_interface import MetadataInformation, DummyInterface


def get_testpath():
    return os.path.join(os.path.dirname(__file__), 'test files', 'csv_data.txt')


def get_testdir():
    return os.path.join(os.path.dirname(__file__), 'test files')


class TestCSVGenerator(unittest.TestCase):
    def setUp(self):
        self.interface = DummyInterface()

    def test_generator(self):
        reader = study_reader.StudyReader('FSDxxxx', True, data_file=get_testpath(), study_path=get_testdir())
        header_info = header_scanner.get_header_info_for_study(get_testpath())
        study = reader.get_study()
        csv_path = os.path.join(get_testdir(), 'daFxxxx.csv')
        csv_generator.create_csv(study, 'fi_FI', 'utf-8', 'daFxxxx.csv', header_info)
        _ = localization.get_translation_func('fi_FI')

        with open(csv_path, encoding='utf-8') as csv_file:
            csv_reader = csv.reader(csv_file, delimiter=';')
            rows = [row for row in csv_reader]

        self.assertEqual(['NUMERO', 'SUKUPUOLI', 'KAUPUNKI', 'AMMATTI', _('Data file'), _('Text')], rows[0])
        self.assertEqual(['111', 'Muu', 'Tampere', 'Hissinapin painaja', 'csv_data.txt', 'Lorem.'], rows[1])