import unittest
import wx
from kvalikirstu2 import argument_parser, gui_utils


class Window(wx.Frame, gui_utils.HotkeyMixin):
    def __init__(self):
        wx.Frame.__init__(self)
        gui_utils.HotkeyMixin.__init__(self)


class FakeKeyEvent:
    def __init__(self, keycode, modifiers):
        self.keycode = keycode
        self.modifiers = modifiers

    def GetKeyCode(self):
        return self.keycode

    def GetModifiers(self):
        return self.modifiers


class TestGUIUtils(unittest.TestCase):
    """Unit tests for the gui_utils module."""
    def setUp(self):
        self.app = wx.App()
        argument_parser.Settings().parse_gui([])

    def test_hotkey_mixin(self):
        mock1 = unittest.mock.MagicMock()
        mock2 = unittest.mock.MagicMock()
        mock3 = unittest.mock.MagicMock()
        window = Window()
        window._add_hotkey(100, wx.MOD_CONTROL, mock1)
        window._add_hotkey(200, wx.MOD_CONTROL, mock2)
        window._add_hotkey(300, wx.MOD_CONTROL, mock3)
        window._key_pressed(FakeKeyEvent(100, wx.MOD_CONTROL))
        window._key_pressed(FakeKeyEvent(300, wx.MOD_CONTROL))
        self.assertTrue(mock1.called)
        self.assertFalse(mock2.called)
        self.assertTrue(mock3.called)
